"use strict";

exports.__esModule = true;
exports.removeEventListener = exports.openURL = exports.getInitialURL = exports.canOpenURL = exports.addEventListener = void 0;
const remote = window.ReactNativeElectron;
const eventHandlers = new Map();

const addEventListener = (type, handler) => {
  if (type === 'url' && typeof handler === 'function') {
    const wrapHandler = (event, url) => {
      handler({
        type,
        url
      });
    };

    eventHandlers.set(handler, wrapHandler);
    remote.appOpenURL.addListener(wrapHandler);
  }
};

exports.addEventListener = addEventListener;

const removeEventListener = (type, handler) => {
  if (type === 'url' && typeof handler === 'function') {
    const wrapHandler = eventHandlers.get(handler);

    if (wrapHandler) {
      remote.appOpenURL.removeListener(wrapHandler);
    }

    eventHandlers.delete(handler);
  }
};

exports.removeEventListener = removeEventListener;

const openURL = async url => {
  await remote.openURL(url);
}; // Apply same behavior as RNW


exports.openURL = openURL;

const canOpenURL = () => Promise.resolve(true);

exports.canOpenURL = canOpenURL;

const getInitialURL = async () => {
  return (await remote.getInitialURL()) || null;
};

exports.getInitialURL = getInitialURL;